<?php
/**
* ޥ͡륤󥿥ե
*
* PHP version 5
*
* @package    interfaces
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

interface ITaskManager extends IObject
{
	/*
	 *   ޥ͡
	 */
	public function init( Config $config );

	/*
	 * 
	 */
	public function getTask( String $task_name );

	/*
	 * ʥåץåȤ
	 */
	public function getSnapshot();

	/**
	 *   ٥ȥǥѥåԤ
	 *
	 */
	public function dispatchEvents( IRequest $request );

	/**
	 *   ٥ȽԤ
	 *
	 */
	public function processEvents();

}

return __FILE__;